==> pretext-2.0.0.dev20230813.tar.gz: pretext-2.0.0.dev20230813/pretext/project/xml.py <==
from pathlib import Path
import shutil
import typing as t
from enum import Enum
import pydantic_xml as pxml


# To prevent circular imports, put this here instead of in `__init__`; however, it's not used in the file.
class Executables(pxml.BaseXmlModel, tag="executables"):
    latex: str = pxml.attr(default="latex")
    pdflatex: str = pxml.attr(default="pdflatex")
    xelatex: str = pxml.attr(default="xelatex")
    pdfsvg: str = pxml.attr(default="pdf2svg")
    # If not specified, use a local executable if it exists; if it doesn't exist, choose `None`, which allows the generation logic to use the server instead.
    asy: t.Optional[str] = pxml.attr(default=shutil.which("asy"))
    # The same applies to Sage.
    sage: t.Optional[str] = pxml.attr(default=shutil.which("sage"))
    pdfpng: str = pxml.attr(default="convert")
    pdfeps: str = pxml.attr(default="pdftops")
    node: str = pxml.attr(default="node")
    liblouis: str = pxml.attr(default="file2brl")


class LegacyFormat(str, Enum):
    HTML = "html"
    HTML_ZIP = "html-zip"
    LATEX = "latex"
    PDF = "pdf"
    EPUB = "epub"
    KINDLE = "kindle"
    BRAILLE_ELECTRONIC = "braille-electronic"
    BRAILLE_EMBOSS = "braille-emboss"
    WEBWORK = "webwork-sets"
    WEBWORK_ZIPPED = "webwork-sets-zipped"
    CUSTOM = "custom"


class LatexEngine(str, Enum):
    XELATEX = "xelatex"
    LATEX = "latex"
    PDFLATEX = "pdflatex"


class StringParam(pxml.BaseXmlModel, tag="stringparam"):
    key: str = pxml.attr()
    value: str = pxml.attr()


class LegacyTarget(pxml.BaseXmlModel, tag="target", search_mode="unordered"):
    name: str = pxml.attr()
    latex_engine: t.Optional[LatexEngine] = pxml.attr(name="pdf-method")
    format: LegacyFormat = pxml.element()
    source: str = pxml.element()
    publication: str = pxml.element()
    output_dir: Path = pxml.element(tag="output-dir")
    output_filename: t.Optional[str] = pxml.element(tag="output-filename")
    # The v1 file called this `deploy-dir`; the v2 file uses `site`.
    site: t.Optional[str] = pxml.element(name="deploy-dir")
    xsl: t.Optional[str] = pxml.element()
    stringparams: t.List[StringParam] = pxml.element(tag="stringparam", default=[])


class LegacyExecutables(pxml.BaseXmlModel, tag="executables", search_mode="unordered"):
    latex: str = pxml.element()
    pdflatex: str = pxml.element()
    xelatex: str = pxml.element()
    pdfsvg: str = pxml.element()
    asy: str = pxml.element()
    sage: str = pxml.element()
    pdfpng: str = pxml.element()
    pdfeps: str = pxml.element()
    node: str = pxml.element()
    liblouis: str = pxml.element()


class LegacyProject(pxml.BaseXmlModel, tag="project", search_mode="unordered"):
    targets: t.List[LegacyTarget] = pxml.wrapped("targets", pxml.element(tag="target"))
    executables: LegacyExecutables = pxml.element()

==> pretext-2.2.1.dev20231028.tar.gz: pretext-2.2.1.dev20231028/pretext/project/xml.py <==
from pathlib import Path
import shutil
import typing as t
from enum import Enum
from pydantic import ConfigDict
import pydantic_xml as pxml
from pydantic_xml.element.element import SearchMode


# To prevent circular imports, put this here instead of in `__init__`; however, it's not used in this file.
class Executables(pxml.BaseXmlModel, tag="executables"):
    model_config = ConfigDict(extra="forbid")
    latex: str = pxml.attr(default="latex")
    pdflatex: str = pxml.attr(default="pdflatex")
    xelatex: str = pxml.attr(default="xelatex")
    pdfsvg: str = pxml.attr(default="pdf2svg")
    # If not specified, use a local executable if it exists; if it doesn't exist, choose `None`, which allows the generation logic to use the server instead.
    asy: t.Optional[str] = pxml.attr(default=shutil.which("asy"))
    # The same applies to Sage.
    sage: t.Optional[str] = pxml.attr(default=shutil.which("sage"))
    pdfpng: str = pxml.attr(default="convert")
    pdfeps: str = pxml.attr(default="pdftops")
    node: str = pxml.attr(default="node")
    liblouis: str = pxml.attr(default="file2brl")


class LegacyFormat(str, Enum):
    HTML = "html"
    HTML_ZIP = "html-zip"
    LATEX = "latex"
    PDF = "pdf"
    EPUB = "epub"
    KINDLE = "kindle"
    BRAILLE_ELECTRONIC = "braille-electronic"
    BRAILLE_EMBOSS = "braille-emboss"
    WEBWORK = "webwork-sets"
    WEBWORK_ZIPPED = "webwork-sets-zipped"
    CUSTOM = "custom"


class LatexEngine(str, Enum):
    XELATEX = "xelatex"
    LATEX = "latex"
    PDFLATEX = "pdflatex"


class LegacyStringParam(pxml.BaseXmlModel):
    model_config = ConfigDict()
    key: str = pxml.attr()
    value: str = pxml.attr()


class LegacyTarget(pxml.BaseXmlModel, tag="target", search_mode=SearchMode.UNORDERED):
    model_config = ConfigDict()
    name: str = pxml.attr()
    latex_engine: t.Optional[LatexEngine] = pxml.attr(name="pdf-method", default=None)
    format: LegacyFormat = pxml.element()
    source: str = pxml.element()
    publication: str = pxml.element()
    output_dir: Path = pxml.element(tag="output-dir")
    output_filename: t.Optional[str] = pxml.element(tag="output-filename", default=None)
    # The v1 file called this `deploy-dir`; the v2 file uses `site`.
    site: t.Optional[str] = pxml.element(name="deploy-dir", default=None)
    xsl: t.Optional[str] = pxml.element(default=None)
    stringparams: t.List[LegacyStringParam] = pxml.element(
        tag="stringparam", default=[]
    )


class LegacyExecutables(
    pxml.BaseXmlModel, tag="executables", search_mode=SearchMode.UNORDERED
):
    model_config = ConfigDict()
    latex: str = pxml.element()
    pdflatex: str = pxml.element()
    xelatex: str = pxml.element()
    pdfsvg: str = pxml.element()
    asy: str = pxml.element()
    sage: str = pxml.element()
    pdfpng: str = pxml.element()
    pdfeps: str = pxml.element()
    node: str = pxml.element()
    liblouis: str = pxml.element()


class LegacyProject(pxml.BaseXmlModel, tag="project", search_mode=SearchMode.UNORDERED):
    model_config = ConfigDict()
    targets: t.List[LegacyTarget] = pxml.wrapped("targets", pxml.element(tag="target"))
    executables: LegacyExecutables = pxml.element()
